const webpack = require('webpack');
const path = require('path');
const MiniCssExtractPlugin = require('mini-css-extract-plugin'); // css uglify
const OptimizeCssAssetsPlugin = require('optimize-css-assets-webpack-plugin'); // css uglify
const LiveReloadPlugin = require('webpack-livereload-plugin');
const SvgStore = require('webpack-svgstore-plugin');
const TerserPlugin = require('terser-webpack-plugin'); // minifi ES6

const sourcePath = path.join(__dirname, 'src');
const buildPath = path.join(__dirname, 'public', 'local', 'dist');

var env = process.env.NODE_ENV ? process.env.NODE_ENV : 'production'

module.exports = {
  entry: path.join(sourcePath, 'scripts', 'app.js'),
  output: {
    path: buildPath,
    filename: 'bundle.js'
  },
  optimization: {
    minimize: env == 'production',
    minimizer: [new TerserPlugin(), new OptimizeCssAssetsPlugin({})],
  },
  module: {
    rules: [
      {
        test: /\.js$/,
        exclude: /node_modules/,
        loader: 'babel-loader',
        query: {
          presets: ['@babel/env']
        },
      },
      {
        test: /\.scss$/,
        exclude: /node_modules/,
        use: [
          {
            loader: MiniCssExtractPlugin.loader,
            options: {
              publicPath: '../',
            },
          },
          'css-loader',
          'postcss-loader',
          'sass-loader',
        ]
      }
    ]
  },
  resolve: {
    modules: [sourcePath, 'node_modules'],
    alias: {
      "TweenLite": path.resolve('node_modules', 'gsap/src/uncompressed/TweenLite.js'),
      "TweenMax": path.resolve('node_modules', 'gsap/src/uncompressed/TweenMax.js'),
      "TimelineLite": path.resolve('node_modules', 'gsap/src/uncompressed/TimelineLite.js'),
      "TimelineMax": path.resolve('node_modules', 'gsap/src/uncompressed/TimelineMax.js'),
      "ScrollMagic": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/ScrollMagic.js'),
      "animation.gsap": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/plugins/animation.gsap.js'),
      "debug.addIndicators": path.resolve('node_modules', 'scrollmagic/scrollmagic/uncompressed/plugins/debug.addIndicators.js')
    }
  },
  plugins: [
    new MiniCssExtractPlugin({
      // Options similar to the same options in webpackOptions.output
      // all options are optional
      filename: 'style.css',
      chunkFilename: '[name].css',
      ignoreOrder: false, // Enable to remove warnings about conflicting order
    }),
    new LiveReloadPlugin(),
    new SvgStore({
        prefix: 'shape-',
        svgoOptions: {
          plugins: [
            { moveGroupAttrsToElems: false },
            { removeTitle: true },
            { cleanupAttrs: true },
            { removeUselessDefs: true },
            { removeEmptyAttrs: true },
            { 
              removeAttrs: {
                attrs: '(stroke|fill)' 
              }
            }
          ]
        }
      }),
    new webpack.ProvidePlugin({
        $: 'jquery',
        jQuery: 'jquery',
        'window.jQuery': 'jquery',
        Popper: ['popper.js', 'default'],
      })
  ]
}